@@ -1,22 +1,26 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis                              #
+# Antimicrobial Resistance (AMR) Analysis for R                        #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
+# Developed at the University of Groningen, the Netherlands, in        #
+# collaboration with non-profit organisations Certe Medical            #
+# Diagnostics & Advice, and University Medical Center Groningen.       # 
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
 # GNU General Public License version 2.0 (GNU GPL-2), as published by  #
 # the Free Software Foundation.                                        #
-#                                                                      #
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.github.io/AMR.    #
+#                                                                      #
+# Visit our website for the full manual and a complete tutorial about  #
+# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
 # ==================================================================== #
 
 context("count.R")
@@ -29,7 +33,7 @@ test_that("counts work", {
   expect_equal(count_all(example_isolates$AMX), n_rsi(example_isolates$AMX))
   
   # AMX resistance in `example_isolates`
-  expect_equal(count_R(example_isolates$AMX), 683)
+  expect_equal(count_R(example_isolates$AMX), 804)
   expect_equal(count_I(example_isolates$AMX), 3)
   expect_equal(suppressWarnings(count_S(example_isolates$AMX)), 543)
   expect_equal(count_R(example_isolates$AMX) + count_I(example_isolates$AMX),
@@ -37,7 +41,7 @@ test_that("counts work", {
   expect_equal(suppressWarnings(count_S(example_isolates$AMX)) + count_I(example_isolates$AMX),
                count_SI(example_isolates$AMX))
   
-  library(dplyr)
+  library(dplyr, warn.conflicts = FALSE)
   expect_equal(example_isolates %>% count_susceptible(AMC), 1433)
   expect_equal(example_isolates %>% count_susceptible(AMC, GEN, only_all_tested = TRUE), 1687)
   expect_equal(example_isolates %>% count_susceptible(AMC, GEN, only_all_tested = FALSE), 1764)
