@@ -1,22 +1,26 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis                              #
+# Antimicrobial Resistance (AMR) Analysis for R                        #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
+# Developed at the University of Groningen, the Netherlands, in        #
+# collaboration with non-profit organisations Certe Medical            #
+# Diagnostics & Advice, and University Medical Center Groningen.       # 
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
 # GNU General Public License version 2.0 (GNU GPL-2), as published by  #
 # the Free Software Foundation.                                        #
-#                                                                      #
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.github.io/AMR.    #
+#                                                                      #
+# Visit our website for the full manual and a complete tutorial about  #
+# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
 # ==================================================================== #
 
 context("eucast_rules.R")
@@ -30,7 +34,13 @@ test_that("EUCAST rules work", {
                c("if_mo_property", "like.is.one_of", "this_value",
                  "and_these_antibiotics", "have_these_values",
                  "then_change_these_antibiotics", "to_value",
-                 "reference.rule", "reference.rule_group"))
+                 "reference.rule", "reference.rule_group",
+                 "reference.version",
+                 "note"))
+  MOs_mentioned <- unique(eucast_rules_file$this_value)
+  MOs_mentioned <- sort(trimws(unlist(strsplit(MOs_mentioned[!is_possibly_regex(MOs_mentioned)], ",", fixed = TRUE))))
+  MOs_test <- suppressWarnings(suppressMessages(mo_name(MOs_mentioned)))
+  expect_length(MOs_mentioned[MOs_test != MOs_mentioned], 0)
   
   expect_error(suppressWarnings(eucast_rules(example_isolates, col_mo = "Non-existing")))
   expect_error(eucast_rules(x = "text"))
@@ -66,12 +76,12 @@ test_that("EUCAST rules work", {
   expect_equal(suppressWarnings(eucast_rules(a, "mo", info = FALSE)), b)
   
   # piperacillin must be R in Enterobacteriaceae when tica is R
-  library(dplyr)
+  library(dplyr, warn.conflicts = FALSE)
   expect_equal(suppressWarnings(
     example_isolates %>%
       mutate(TIC = as.rsi("R"),
              PIP = as.rsi("S")) %>%
-      eucast_rules(col_mo = "mo") %>%
+      eucast_rules(col_mo = "mo", version_expertrules = 3.1) %>%
       left_join_microorganisms() %>%
       filter(family == "Enterobacteriaceae") %>%
       pull(PIP) %>%
@@ -79,12 +89,13 @@ test_that("EUCAST rules work", {
       as.character()),
     "R")
   
-  # Azithromicin and Clarythromycin must be equal to Erythromycin
+  # Azithromycin and Clarythromycin must be equal to Erythromycin
   a <- eucast_rules(data.frame(mo = example_isolates$mo,
                                ERY = example_isolates$ERY,
                                AZM = as.rsi("R"),
                                CLR = as.rsi("R"),
-                               stringsAsFactors = FALSE))$CLR
+                               stringsAsFactors = FALSE),
+                    version_expertrules = 3.1)$CLR
   b <- example_isolates$ERY
   expect_identical(a[!is.na(b)],
                    b[!is.na(b)])
