@@ -1,22 +1,26 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis                              #
+# Antimicrobial Resistance (AMR) Analysis for R                        #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
+# Developed at the University of Groningen, the Netherlands, in        #
+# collaboration with non-profit organisations Certe Medical            #
+# Diagnostics & Advice, and University Medical Center Groningen.       # 
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
 # GNU General Public License version 2.0 (GNU GPL-2), as published by  #
 # the Free Software Foundation.                                        #
-#                                                                      #
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.github.io/AMR.    #
+#                                                                      #
+# Visit our website for the full manual and a complete tutorial about  #
+# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
 # ==================================================================== #
 
 context("mo_property.R")
@@ -54,7 +58,7 @@ test_that("mo_property works", {
   expect_equal(mo_year("Escherichia coli"), 1919)
 
   expect_equal(mo_shortname("Escherichia coli"), "E. coli")
-  expect_equal(mo_shortname("Escherichia"), "E. spp.")
+  expect_equal(mo_shortname("Escherichia"), "Escherichia")
   expect_equal(mo_shortname("Staphylococcus aureus"), "S. aureus")
   expect_equal(mo_shortname("Staphylococcus aureus", Becker = TRUE), "S. aureus")
   expect_equal(mo_shortname("Staphylococcus aureus", Becker = "all", language = "en"), "CoPS")
